@@ -18,13 +18,14 @@ module Errors
 
   class FileUnavailable < RecognizedError
     def to_str
-      "An MP4 URL was found, but the download failed."
+      "The programme file is not currently available.\n"+
+      "If it's new, try again later."
     end
   end
   
   class MP4Unavailable < RecognizedError
     def to_str
-      "This programme is not currently available in an MP4 version."
+      "This programme is not currently available in an MP3 or MPEG4 version."
     end
   end
 
